@@ -64,6 +64,25 @@ def haveSpread():
     """
     return _spreadAvailable
 
+__defaultTransportsRegistered = False
+__transportRegistrationLock = threading.RLock()
+def __registerDefaultTransports():
+    """
+    Registers all available transports.
+    """
+    global __defaultTransportsRegistered
+    with __transportRegistrationLock:
+        if __defaultTransportsRegistered:
+            return
+        __defaultTransportsRegistered = True
+        import rsb.transport.local
+        rsb.transport.local.initialize()
+        import rsb.transport.socket
+        rsb.transport.socket.initialize()
+        if haveSpread():
+            import rsb.transport.rsbspread
+            rsb.transport.rsbspread.initialize()
+
 class QualityOfServiceSpec(object):
     """
     Specification of desired quality of service settings for sending
@@ -187,7 +206,7 @@ def _configDefaultSourcesToDict(defaults={}):
     if 'transport.socket.enabled' not in defaults:
         defaults['transport.socket.enabled'] = '1'
     if 'introspection.enabled' not in defaults:
-        defaults['introspection.enabled'] = '0'
+        defaults['introspection.enabled'] = '1'
     if platform.system() == 'Windows':
         partial = _configFileToDict("c:\\rsb.conf", defaults)
     else:
@@ -369,7 +388,7 @@ class ParticipantConfig (object):
 
         # Introspection options
         introspectionOptions = dict(sectionOptions('introspection'))
-        result.__introspection = _configValueIsTrue(introspectionOptions.get('enabled', '0'))
+        result.__introspection = _configValueIsTrue(introspectionOptions.get('enabled', '1'))
 
         return result
 
@@ -927,7 +946,7 @@ class Event(object):
     """
 
     def __init__(self, id = None, scope = Scope("/"), method = None,
-                 data = None, type = None,
+                 data = None, type = object,
                  metaData=None, userInfos=None, userTimes=None, causes = None):
         """
         Constructs a new event with undefined type, root scope and no data.
@@ -962,6 +981,8 @@ class Event(object):
         self.__scope = Scope.ensureScope(scope)
         self.__method = method
         self.__data = data
+        if type is None:
+            raise ValueError("Type must not be None")
         self.__type = type
         if metaData is None:
             self.__metaData = MetaData()
@@ -1293,36 +1314,18 @@ class Participant(object):
 
         transports = []
         for transport in config.getTransports():
-            if transport.getName() == 'spread':
-                if not haveSpread():
-                    raise ValueError, "Spread transport not enabled as the python spread module cannot be found in the running interpreter"
-                from transport import rsbspread
-                if direction == 'in':
-                    klass = rsbspread.InConnector
-                elif direction == 'out':
-                    klass = rsbspread.OutConnector
-                else:
-                    assert(False)
-            elif transport.getName() == 'socket':
-                import rsb.transport.socket
-                if direction == 'in':
-                    klass = rsb.transport.socket.InPushConnector
-                elif direction == 'out':
-                    klass = rsb.transport.socket.OutConnector
-                else:
-                    assert(False)
-            elif transport.getName() == 'inprocess':
-                import rsb.transport.local
-                if direction == 'in':
-                    klass = rsb.transport.local.InConnector
-                elif direction == 'out':
-                    klass = rsb.transport.local.OutConnector
-                else:
-                    assert(False)
+            factory = rsb.transport.getTransportFactory(transport.getName())
+            converters = convertersFromTransportConfig(transport)
+            if direction == 'in':
+                transports.append(
+                    factory.createInPushConnector(converters,
+                                                  transport.getOptions()))
+            elif direction == 'out':
+                transports.append(
+                    factory.createOutConnector(converters,
+                                               transport.getOptions()))
             else:
-                raise ValueError, 'No such transport: "%s"' % transport.getName()
-            transports.append(klass(converters = convertersFromTransportConfig(transport),
-                                    options    = transport.getOptions()))
+                assert(False)
         return transports
 
 class Informer(Participant):
@@ -1360,6 +1363,8 @@ class Informer(Participant):
         self.__logger = getLoggerByClass(self.__class__)
 
         # TODO check that type can be converted
+        if dataType is None:
+            raise ValueError("dataType must not be None")
         self.__type           = dataType
         self.__sequenceNumber = 0
         self.__configurator   = None
@@ -1632,6 +1637,7 @@ def _initializeIntrospection():
 def createParticipant(clazz, scope, config, parent = None, **kwargs):
     if config is None:
         config = getDefaultParticipantConfig()
+    __registerDefaultTransports()
 
     if config.introspection:
         _initializeIntrospection()
